@@ -1,6 +1,7 @@
 // Filename: component_config.rs
-// Version:	 0.8
-// Date:	 27-07-2021 (DD-MM-YYYY)
+// Version:	 0.9
+// Date:	 15-09-2021 (DD-MM-YYYY)
+// Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
 // This program is free software: you can redistribute it and/or modify
@@ -27,8 +28,13 @@ mod fetch;
 mod memory_controller;
 #[doc(hidden)]
 mod pipeline;
+#[doc(hidden)]
+mod register_file;
+#[doc(hidden)]
+mod scheduler;
 
 pub use cache::{CacheConfig, CacheType};
 pub use fetch::FetchConfig;
 pub use memory_controller::MemoryControllerConfig;
-pub use pipeline::{default_latencies, InstructionLatencies, PipelineConfig};
+pub use pipeline::{AluCapabilities, PipelineConfig};
+pub use scheduler::SchedulerConfig;
